@@ -1,7 +1,6 @@
 use super::{Key, Nonce};
 
-use std::fmt;
-use std::cmp;
+use std::{fmt, cmp};
 
 use x25519_dalek as x;
 
@@ -11,36 +10,32 @@ pub struct SharedSecret {
 }
 
 impl SharedSecret {
+	pub const LEN: usize = 32;
+
+	pub(crate) fn from_shared_secret(inner: x::SharedSecret) -> Self {
+		Self { inner }
+	}
+
 	// nonce size U24
 	/// ## Warning
 	/// Don't call this function with the same nonce again.
 	/// This probably leads to an insecure key.
 	pub fn to_key(&self, initial_nonce: Nonce) -> Key {
-		Key::new(self.to_bytes(), initial_nonce.into_inner())
+		Key::new(self.to_bytes(), initial_nonce.into_bytes())
 	}
 
 	fn to_bytes(&self) -> [u8; 32] {
 		self.inner.to_bytes()
 	}
 
-	pub fn as_bytes(&self) -> &[u8; 32] {
-		self.inner.as_bytes()
-	}
-
-	pub fn as_slice(&self) -> &[u8] {
+	pub(crate) fn as_slice(&self) -> &[u8] {
 		self.inner.as_bytes()
 	}
 }
 
 impl fmt::Debug for SharedSecret {
 	fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-		write!(f, "SharedSecret")
-	}
-}
-
-impl From<x::SharedSecret> for SharedSecret {
-	fn from(inner: x::SharedSecret) -> Self {
-		Self { inner }
+		f.write_str("SharedSecret")
 	}
 }
 
