@@ -17,7 +17,7 @@ pub struct Keypair {
 impl Keypair {
 	pub const LEN: usize = 32;
 
-	pub fn generate() -> Self {
+	pub fn new() -> Self {
 		Self::from_keypair(ed::Keypair::generate(&mut OsRng))
 	}
 
@@ -94,3 +94,6 @@ impl Clone for Keypair {
 		Self::from_bytes(self.to_bytes())
 	}
 }
+
+#[cfg(all(feature = "serde", feature = "b64"))]
+impl_serde!(Keypair, 43);
\ No newline at end of file
